class Comparison:
    """
    Instantiate a comparison operation.
    Numbers will be multiplied by the given multiplier.

    :param multiplier: The multiplier.
    :type multiplier: int
    """

    def __init__(self):
        pass
    def compare_short_routes(self, model1, model2):
        """
        Multiply a given number by the multiplier.

        :param model1: The model to compare.
        :param model2: The model to compare.
        :type pytorch model
        :return: The result of the multiplication.
        :rtype: boolean
        """

        return True

